==> builders_inventory-2.1.4-sources.jar: _3650/builders_inventory/feature/extended_inventory/ExtendedInventoryRenameScreen.java <==
package _3650.builders_inventory.feature.extended_inventory;

import org.lwjgl.glfw.GLFW;

import _3650.builders_inventory.BuildersInventory;
import _3650.builders_inventory.api.util.GuiUtil;
import _3650.builders_inventory.api.widgets.exbutton.ExtendedImageButton;
import _3650.builders_inventory.api.widgets.exbutton.ExtendedImageButtonGui;
import _3650.builders_inventory.config.Config;
import net.minecraft.class_124;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_332;
import net.minecraft.class_342;
import net.minecraft.class_364;
import net.minecraft.class_4068;
import net.minecraft.class_437;
import net.minecraft.class_6379;
import net.minecraft.class_8666;

public class ExtendedInventoryRenameScreen extends class_437 {
	
	private static final class_2960 BACKGROUND = BuildersInventory.modLoc("textures/gui/container/extended_inventory/rename.png");
	
	private static final class_8666 SPRITES_BUTTON_CONFIRM = new class_8666(
			BuildersInventory.modLoc("extended_inventory/rename/button_confirm"),
			BuildersInventory.modLoc("extended_inventory/rename/button_confirm_highlighted"));
	private static final class_8666 SPRITES_BUTTON_CANCEL = new class_8666(
			BuildersInventory.modLoc("extended_inventory/rename/button_cancel"),
			BuildersInventory.modLoc("extended_inventory/rename/button_cancel_highlighted"));
	private static final class_8666 SPRITES_BUTTON_CLEAR = new class_8666(
			BuildersInventory.modLoc("extended_inventory/rename/button_clear"),
			BuildersInventory.modLoc("extended_inventory/rename/button_clear_highlighted"));
	
	private final ExtendedImageButtonGui exGui = new ExtendedImageButtonGui();
	private final int imageWidth;
	private final int imageHeight;
	
	private int leftPos;
	private int topPos;
	private class_342 name;
	
	protected ExtendedInventoryRenameScreen(int page) {
		super(class_2561.method_43469("container.builders_inventory.extended_inventory.rename", page + 1));
		this.imageWidth = 198;
		this.imageHeight = 54;
	}
	
	@Override
	protected void method_25426() {
		super.method_25426();
		this.exGui.init();
		this.leftPos = (this.field_22789 - this.imageWidth) / 2;
		this.topPos = (this.field_22790 - this.imageHeight) / 2;
		
		// Text Field
		this.name = new class_342(this.field_22793, this.leftPos + 22, this.topPos + 23, 154, 12, class_2561.method_43473());
		this.name.method_1856(false);
		this.name.method_1868(-1);
		this.name.method_1860(-1);
		this.name.method_1858(false);
		this.name.method_1880(22);
		this.name.method_1852(ExtendedInventory.getPageName());
		this.method_37063(this.name);
		
		// Buttons
		this.method_37063(new ExtendedImageButton(this.leftPos + 180, this.topPos + 20, 14, 14,
				SPRITES_BUTTON_CONFIRM,
				button -> {
					this.confirmPageName();
					ExtendedInventory.open(this.field_22787);
				},
				class_2561.method_43471("container.builders_inventory.extended_inventory.rename.tooltip.button.confirm").method_27692(class_124.field_1068)));
		this.method_37063(new ExtendedImageButton(this.leftPos + 181, this.topPos + 5, 12, 12,
				SPRITES_BUTTON_CANCEL,
				button -> {
					ExtendedInventory.open(this.field_22787);
				},
				class_2561.method_43471("container.builders_inventory.extended_inventory.rename.tooltip.button.cancel").method_27692(class_124.field_1068)));
		this.method_37063(new ExtendedImageButton(this.leftPos + 5, this.topPos + 21, 12, 12,
				SPRITES_BUTTON_CLEAR,
				button -> {
					this.name.method_1852("");
				},
				class_2561.method_43471("container.builders_inventory.extended_inventory.rename.tooltip.button.clear").method_27692(class_124.field_1068)));
	}
	
	@Override
	protected void method_56131() {
		this.method_48265(this.name);
	}
	
	@Override
	protected void method_41843() {
		String text = this.name.method_1882();
		super.method_41843();
		this.name.method_1852(text);
	}
	
	private void confirmPageName() {
		String name = this.name.method_1882();
		ExtendedInventory.setPageName(name.isBlank() ? "" : name);
	}
	
	@Override
	public boolean method_25404(int keyCode, int scanCode, int modifiers) {
		if (keyCode == GLFW.GLFW_KEY_ENTER || keyCode == GLFW.GLFW_KEY_KP_ENTER) {
			confirmPageName();
			ExtendedInventory.open(this.field_22787);
			return true;
		} else return super.method_25404(keyCode, scanCode, modifiers);
	}
	
	@Override
	public void method_25419() {
		if (Config.instance().extended_inventory_close_to_main) {
			ExtendedInventory.open(this.field_22787);
		} else super.method_25419();
	}
	
	@Override
	protected <T extends class_364 & class_4068 & class_6379> T method_37063(T widget) {
		this.exGui.addRenderableWidget(widget);
		return super.method_37063(widget);
	}
	
	@Override
	protected void method_37067() {
		this.exGui.clearWidgets();
		super.method_37067();
	}
	
	@Override
	public void method_25394(class_332 gui, int mouseX, int mouseY, float partialTick) {
		super.method_25394(gui, mouseX, mouseY, partialTick);
		
		gui.method_51439(this.field_22793, this.field_22785, this.leftPos + 8, this.topPos + 6, 0x404040, false);
		
		this.exGui.renderTooltip(this.field_22793, gui, mouseX, mouseY);
	}
	
	@Override
	public void method_25420(class_332 gui, int mouseX, int mouseY, float partialTick) {
		this.method_52752(gui);
		GuiUtil.blitScreenBackground(gui, BACKGROUND, this.leftPos, this.topPos, this.imageWidth, this.imageHeight);
	}
	
	@Override
	public boolean method_25421() {
		return false;
	}
	
}

==> builders_inventory-2.2.0-sources.jar: _3650/builders_inventory/feature/extended_inventory/ExtendedInventoryRenameScreen.java <==
package _3650.builders_inventory.feature.extended_inventory;

import org.lwjgl.glfw.GLFW;

import _3650.builders_inventory.BuildersInventory;
import _3650.builders_inventory.api.widgets.exbutton.ExtendedImageButton;
import _3650.builders_inventory.api.widgets.exbutton.ExtendedImageButtonGui;
import _3650.builders_inventory.config.Config;
import net.minecraft.class_124;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_332;
import net.minecraft.class_342;
import net.minecraft.class_364;
import net.minecraft.class_4068;
import net.minecraft.class_437;
import net.minecraft.class_6379;
import net.minecraft.class_8666;

public class ExtendedInventoryRenameScreen extends class_437 {
	
	private static final class_2960 BACKGROUND = BuildersInventory.modLoc("textures/gui/container/extended_inventory/rename.png");
	
	private static final class_8666 SPRITES_BUTTON_CONFIRM = new class_8666(
			BuildersInventory.modLoc("extended_inventory/rename/button_confirm"),
			BuildersInventory.modLoc("extended_inventory/rename/button_confirm_highlighted"));
	private static final class_8666 SPRITES_BUTTON_CANCEL = new class_8666(
			BuildersInventory.modLoc("extended_inventory/rename/button_cancel"),
			BuildersInventory.modLoc("extended_inventory/rename/button_cancel_highlighted"));
	private static final class_8666 SPRITES_BUTTON_CLEAR = new class_8666(
			BuildersInventory.modLoc("extended_inventory/rename/button_clear"),
			BuildersInventory.modLoc("extended_inventory/rename/button_clear_highlighted"));
	
	private final ExtendedImageButtonGui exGui = new ExtendedImageButtonGui();
	private final int imageWidth;
	private final int imageHeight;
	
	private int leftPos;
	private int topPos;
	private class_342 name;
	
	protected ExtendedInventoryRenameScreen(int page) {
		super(class_2561.method_43469("container.builders_inventory.extended_inventory.rename", page + 1));
		this.imageWidth = 198;
		this.imageHeight = 54;
	}
	
	@Override
	protected void method_25426() {
		super.method_25426();
		this.exGui.init();
		this.leftPos = (this.field_22789 - this.imageWidth) / 2;
		this.topPos = (this.field_22790 - this.imageHeight) / 2;
		
		// Text Field
		this.name = new class_342(this.field_22793, this.leftPos + 22, this.topPos + 23, 154, 12, class_2561.method_43473());
		this.name.method_1856(false);
		this.name.method_1868(-1);
		this.name.method_1860(-1);
		this.name.method_1858(false);
		this.name.method_1880(22);
		this.name.method_1852(ExtendedInventory.getPageName());
		this.method_37063(this.name);
		
		// Buttons
		this.method_37063(new ExtendedImageButton(this.leftPos + 180, this.topPos + 20, 14, 14,
				SPRITES_BUTTON_CONFIRM,
				button -> {
					this.confirmPageName();
					ExtendedInventory.open(this.field_22787);
				},
				class_2561.method_43471("container.builders_inventory.extended_inventory.rename.tooltip.button.confirm").method_27692(class_124.field_1068)));
		this.method_37063(new ExtendedImageButton(this.leftPos + 181, this.topPos + 5, 12, 12,
				SPRITES_BUTTON_CANCEL,
				button -> {
					ExtendedInventory.open(this.field_22787);
				},
				class_2561.method_43471("container.builders_inventory.extended_inventory.rename.tooltip.button.cancel").method_27692(class_124.field_1068)));
		this.method_37063(new ExtendedImageButton(this.leftPos + 5, this.topPos + 21, 12, 12,
				SPRITES_BUTTON_CLEAR,
				button -> {
					this.name.method_1852("");
				},
				class_2561.method_43471("container.builders_inventory.extended_inventory.rename.tooltip.button.clear").method_27692(class_124.field_1068)));
	}
	
	@Override
	protected void method_56131() {
		this.method_48265(this.name);
	}
	
	@Override
	protected void method_41843() {
		String text = this.name.method_1882();
		super.method_41843();
		this.name.method_1852(text);
	}
	
	private void confirmPageName() {
		String name = this.name.method_1882();
		ExtendedInventory.setPageName(name.isBlank() ? "" : name);
	}
	
	@Override
	public boolean method_25404(int keyCode, int scanCode, int modifiers) {
		if (keyCode == GLFW.GLFW_KEY_ENTER || keyCode == GLFW.GLFW_KEY_KP_ENTER) {
			confirmPageName();
			ExtendedInventory.open(this.field_22787);
			return true;
		} else return super.method_25404(keyCode, scanCode, modifiers);
	}
	
	@Override
	public void method_25419() {
		if (Config.instance().extended_inventory_close_to_main) {
			ExtendedInventory.open(this.field_22787);
		} else super.method_25419();
	}
	
	@Override
	protected <T extends class_364 & class_4068 & class_6379> T method_37063(T widget) {
		this.exGui.addRenderableWidget(widget);
		return super.method_37063(widget);
	}
	
	@Override
	protected void method_37067() {
		this.exGui.clearWidgets();
		super.method_37067();
	}
	
	@Override
	public void method_25394(class_332 gui, int mouseX, int mouseY, float partialTick) {
		super.method_25394(gui, mouseX, mouseY, partialTick);
		
		gui.method_51439(this.field_22793, this.field_22785, this.leftPos + 8, this.topPos + 6, 0xFF404040, false);
		
		this.exGui.renderTooltip(this.field_22793, gui, mouseX, mouseY);
	}
	
	@Override
	public void method_25420(class_332 gui, int mouseX, int mouseY, float partialTick) {
		this.method_52752(gui);
		gui.method_25302(BACKGROUND, this.leftPos, this.topPos, 0, 0, this.imageWidth, this.imageHeight);
	}
	
	@Override
	public boolean method_25421() {
		return false;
	}
	
}
